# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-12-01 15:33
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import ishtar_common.models_common
import re


class Migration(migrations.Migration):

    dependencies = [
        ('ishtar_common', '0203_auto_20200407_1142'),
    ]

    operations = [
        migrations.CreateModel(
            name='DocumentTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, null=True, verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
            ],
            options={
                'verbose_name': 'Document tag',
                'verbose_name_plural': 'Document tags',
                'ordering': ('label',),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='Language',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, null=True, verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('iso_code', models.CharField(blank=True, max_length=2, null=True, verbose_name='ISO code')),
            ],
            options={
                'verbose_name': 'Language',
                'verbose_name_plural': 'Languages',
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.AlterModelOptions(
            name='sourcetype',
            options={'ordering': ['label'], 'verbose_name': 'Document type', 'verbose_name_plural': 'Document types'},
        ),
        migrations.AddField(
            model_name='document',
            name='complete_identifier',
            field=models.TextField(blank=True, null=True, verbose_name='Complete identifier'),
        ),
        migrations.AddField(
            model_name='document',
            name='container_id',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Container ID'),
        ),
        migrations.AddField(
            model_name='document',
            name='container_ref_id',
            field=models.PositiveIntegerField(blank=True, null=True, verbose_name='Container ID'),
        ),
        migrations.AddField(
            model_name='document',
            name='custom_index',
            field=models.IntegerField(blank=True, null=True, verbose_name='Custom index'),
        ),
        migrations.AddField(
            model_name='document',
            name='isbn',
            field=models.CharField(blank=True, max_length=17, null=True, verbose_name='ISBN'),
        ),
        migrations.AddField(
            model_name='document',
            name='issn',
            field=models.CharField(blank=True, max_length=10, null=True, verbose_name='ISSN'),
        ),
        migrations.AddField(
            model_name='document',
            name='publisher',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='publish', to='ishtar_common.Organization', verbose_name='Publisher'),
        ),
        migrations.AddField(
            model_name='document',
            name='source',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='ishtar_common.Document', verbose_name='Source'),
        ),
        migrations.AddField(
            model_name='document',
            name='source_free_input',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='Source - free input'),
        ),
        migrations.AddField(
            model_name='document',
            name='source_page_range',
            field=models.CharField(blank=True, max_length=500, null=True, verbose_name='Source - page range'),
        ),
        migrations.AddField(
            model_name='format',
            name='document_types',
            field=models.ManyToManyField(blank=True, help_text='Only available for these document types', related_name='formats', to='ishtar_common.SourceType'),
        ),
        migrations.AddField(
            model_name='format',
            name='iframe_template',
            field=models.TextField(blank=True, default='', help_text='Template to insert an iframe for this format. Use django template with a {{document}} variable matching the current document.', verbose_name='Iframe template'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='basefind_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage base find complete identifier.', verbose_name='Base find complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='basefind_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage base find custom index. Separate keys with a semicolon.', verbose_name='Base find custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='container_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage container complete identifier.', verbose_name='Container complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='container_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used  to manage container custom index. Separate keys with a semicolon.', verbose_name='Container custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='contextrecord_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage context record complete identifier.', verbose_name='Context record complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='contextrecord_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage context record custom index. Separate keys with a semicolon.', verbose_name='Context record custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='document_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage document complete identifier.', verbose_name='Document complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='document_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage document custom index. Separate keys with a semicolon.', verbose_name='Document custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='file_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage archaeological file complete identifier.', verbose_name='Archaeological file complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='file_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage archaeological file custom index. Separate keys with a semicolon.', verbose_name='Archaeological file custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='find_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage find complete identifier.', verbose_name='Find complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='find_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage find custom index. Separate keys with a semicolon.', verbose_name='Find custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='operation_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage operation complete identifier.', verbose_name='Operation complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='operation_custom_index',
            field=models.TextField(blank=True, default='', help_text='Keys to be used to manage operation custom index. Separate keys with a semicolon.', verbose_name='Operation custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='site_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage archaeological site complete identifier.', verbose_name='Archaeological site complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='site_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage archaeological site custom index. Separate keys with a semicolon.', verbose_name='Archaeological site custom index key'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='warehouse_complete_identifier',
            field=models.TextField(blank=True, default='', help_text='Formula to manage warehouse complete identifier.', verbose_name='Warehouse complete identifier'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='warehouse_custom_index',
            field=models.TextField(blank=True, default='', help_text='Key to be used to manage warehouse custom index. Separate keys with a semicolon.', verbose_name='Warehouse custom index key'),
        ),
        migrations.AddField(
            model_name='sourcetype',
            name='code',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='Code'),
        ),
        migrations.AddField(
            model_name='sourcetype',
            name='coins_genre',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='COInS export - genre'),
        ),
        migrations.AddField(
            model_name='sourcetype',
            name='coins_type',
            field=models.CharField(default='document', max_length=100, verbose_name='COInS export - type'),
        ),
        migrations.AddField(
            model_name='sourcetype',
            name='is_localized',
            field=models.BooleanField(default=False, help_text='Setting a language for this type of document is relevant', verbose_name='Is localized'),
        ),
        migrations.AddField(
            model_name='supporttype',
            name='document_types',
            field=models.ManyToManyField(blank=True, help_text='Only available for these document types', related_name='supports', to='ishtar_common.SourceType'),
        ),
        migrations.AlterField(
            model_name='document',
            name='support_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ishtar_common.SupportType', verbose_name='Medium'),
        ),
        migrations.AlterField(
            model_name='import',
            name='csv_sep',
            field=models.CharField(choices=[(',', ','), (';', ';'), ('|', '|')], default=',', help_text='Separator for CSV file. Standard is comma but Microsoft Excel do not follow this standard and use semi-colon.', max_length=1, verbose_name='CSV separator'),
        ),
        migrations.AlterField(
            model_name='importercolumn',
            name='regexp_pre_filter',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='columns', to='ishtar_common.Regexp'),
        ),
        migrations.AlterField(
            model_name='importercolumn',
            name='value_format',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='columns', to='ishtar_common.ValueFormater'),
        ),
        migrations.AlterField(
            model_name='importertype',
            name='associated_models',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='importer_type_associated', to='ishtar_common.ImporterModel', verbose_name='Associated model'),
        ),
        migrations.AlterField(
            model_name='importertype',
            name='created_models',
            field=models.ManyToManyField(blank=True, help_text='Leave blank for no restrictions', related_name='importer_type_created', to='ishtar_common.ImporterModel', verbose_name='Models that can accept new items'),
        ),
        migrations.AlterField(
            model_name='importtarget',
            name='formater_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='targets', to='ishtar_common.FormaterType'),
        ),
        migrations.AddField(
            model_name='document',
            name='language',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ishtar_common.Language', verbose_name='Language'),
        ),
        migrations.AddField(
            model_name='document',
            name='tags',
            field=models.ManyToManyField(blank=True, to='ishtar_common.DocumentTag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='default_language',
            field=models.ForeignKey(blank=True, help_text='If set, by default the selected language will be set for localized documents.', null=True, on_delete=django.db.models.deletion.CASCADE, to='ishtar_common.Language', verbose_name='Default language for documentation'),
        ),
    ]
